require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.text.InputType"
import "android.os.Vibrator"
import "com.androlua.*"

-- Función para hacer vibrar el dispositivo
function vibrar(ms)
  local vibrator = service.getSystemService(Context.VIBRATOR_SERVICE)
  vibrator.vibrate(ms)
end

-- Función para generar botones de una tabla de multiplicar específica
function generarTabla(numero)
  local botones = {}
  for j = 1, 10 do
    local multiplicacion = numero .. " × " .. j
    local resultado = numero * j
    table.insert(botones, {
      Button,
      text = multiplicacion,
      layout_width = "wrap_content",
      layout_height = "wrap_content",
      onClick = function()
        vibrar(50) -- Vibrar al tocar cada multiplicación
        service.asyncSpeak(multiplicacion .. " es igual a " .. resultado)
      end
    })
  end
  return botones
end

-- Layout principal
local layout = {
  ScrollView,
  layout_width = "match_parent",
  layout_height = "match_parent",
  {
    LinearLayout,
    orientation = "vertical",
    layout_width = "match_parent",
    layout_height = "wrap_content",
    padding = "16dp",

    {
      TextView,
      text = "Tablas de multiplicar por un mundo más accesible",
      textSize = "18sp",
      gravity = "center",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      padding = "8dp",
    },

    {
      LinearLayout,
      orientation = "horizontal", -- EditText y botón en una fila
      layout_width = "match_parent",
      layout_height = "wrap_content",

      {
        EditText,
        id = "inputNumero",
        hint = "Ingrese un número del 1 al 10",
        inputType = "number",
        layout_width = "0dp",
        layout_weight = "1",
        layout_height = "wrap_content",
      },

      {
        Button,
        id = "btnBorrar",
        text = "Borrar consulta",
        layout_width = "wrap_content",
        layout_height = "wrap_content",
        onClick = function()
          inputNumero.setText("")
          vibrar(50) -- Vibrar al borrar
        end
      }
    },

    {
      Button,
      text = "Mostrar tabla",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      layout_marginTop = "8dp",
      onClick = function()
        vibrar(80) -- Vibrar al tocar el botón
        local numero = tonumber(inputNumero.text)
        if numero and numero >= 1 and numero <= 10 then
          contenedorTablas.removeAllViews()
          local botones = generarTabla(numero)
          for i = 1, #botones do
            contenedorTablas.addView(loadlayout(botones[i]))
          end
        else
          vibrar(200) -- Vibración larga si el número es inválido
          service.showToast("Por favor ingrese un número válido del 1 al 10")
        end
      end
    },

    {
      GridLayout,
      id = "contenedorTablas",
      columnCount = 2,
      layout_width = "match_parent",
      layout_height = "wrap_content",
      layout_marginTop = "16dp",
    },

    {
      Button,
      text = "Navegar hacia arriba",
      layout_width = "match_parent",
      layout_height = "wrap_content",
      layout_marginTop = "16dp",
      onClick = function()
        vibrar(60) -- Vibrar al salir
        service.asyncSpeak("Saliendo del complemento") -- Leer el mensaje
        dlg.dismiss() -- Cerrar el diálogo
      end
    }
  }
}

-- Crear y mostrar el diálogo
dlg = LuaDialog(service)
dlg.View = loadlayout(layout)
dlg.show()

-- Vibrar automáticamente al abrir
vibrar(100) -- Vibrar 100ms al iniciar